nx.data.Edge - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.data.Edge Class

Extends nx.data.ObservableObject
Module: nx.data

Edge

- Index
- Methods
- Properties

## Item Index

### Methods

- clearBinding
- dispose
- get
- getBinding
- getData
- gets
- has
- notify
- set
- setBinding
- unwatch

### Properties

- generated
- graph
- id
- line
- linkKey
- parentEdgeSet
- position
- reverse
- reverseLinkKey
- source
- sourceID
- target
- targetID
- type
- updated

## Methods

### ``

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

### `clearBinding`

(

- `prop`

)

Inherited from nx.Observable:

Clear binding for specified property.

#### Parameters:

- `prop` Object

### `dispose`

()

Inherited from nx.Observable

Dispose current object.

### `get`

(

- `name`

)

Inherited from nx.data.ObservableObject:

Get specified property value.

#### Parameters:

- `name` String

#### Returns:

:

### `getBinding`

(

- `prop`

)

Inherited from nx.Observable:

Get existing binding object for specified property.

#### Parameters:

- `prop` Object

#### Returns:

:

### `getData`

() Object

Get original data

#### Returns:

Object:

### `gets`

() Object

Inherited from nx.data.ObservableObject:

Get all properties.

#### Returns:

Object:

### `has`

(

- `name`

)
Boolean

Inherited from nx.data.ObservableObject:

Check whether current object has specified property.

#### Parameters:

- `name` String

#### Returns:

Boolean:

### `notify`

(

- `names`
- `oldValue`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `oldValue` Object

### `set`

(

- `name`
- `value`

)

Inherited from nx.data.ObservableObject:

Set specified property value.

#### Parameters:

- `name` String
- `value`

### `setBinding`

(

- `prop`
- `expr`
- `source`

)

Inherited from nx.Observable:

Set binding for specified property.

#### Parameters:

- `prop` Object
- `expr` Object
- `source` Object

### `unwatch`

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

## Properties

### `generated`

Boolean

Status property,tag is this edge generated

Default: false

### `graph`

nx.data.ObservableGraph

Graph instance

### `id`

String | Number

Edge's id

### `line`

nx.geometry.Line

Edge line object

### `linkKey`

String

Edge's linkkey, linkkey = sourceID-targetID

### `parentEdgeSet`

nx.data.edgeSet

Edge's parent edge set

### `position`

Object

Edge position object {{x1: (Number), y1: (Number), x2: (Number), y2: (Number)}}

### `reverse`

Boolean

Is this link is a reverse link

### `reverseLinkKey`

String

Edge's reverse linkkey,reverseLinkKey = targetID + '_' + sourceID

### `source`

nx.data.Vertex

Source vertex

### `sourceID`

String | Number

Source vertex id

### `target`

nx.data.Vertex

Target vertex

### `targetID`

String | Number

Target vertex id

### `type`

String

Edge's type

Default: edge

### `updated`

Boolean

Status property,tag is this edge updated

Default: false